=========
Changelog
=========

Version 0.0.4
=============
- First auto release with travis
    - Use `Travis AWS`_
    - Use travis.com instead of travis.org

Version 0.0.3
=============
- Also use Hyperlink or Text29 URL field to find related issues
- Added documentation on how to fix the OpenURL Problem
- Fixed some sync bugs

Version 0.0.2
=============
- Documentation Only Changes
    - Add Badges
    - Import Readme to documentation
    - Allow build of documentation even without pywin32 installed
    - Use ReadTheDoc Sphinx Theme

Version 0.0.1
=============

- First Release

.. _Travis AWS: https://blog.travis-ci.com/2020-09-11-arm-on-aws